@@ -111,11 +111,9 @@ void KCModuleQml::showEvent(QShowEvent *event)
     widget->setResizeMode(QQuickWidget::SizeRootObjectToView);
     d->quickWindow = widget->quickWindow();
     d->quickWindow->setColor(QGuiApplication::palette().window().color());
-#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
     connect(qApp, &QGuiApplication::paletteChanged, [=]() {
         d->quickWindow->setColor(QGuiApplication::palette().window().color());
     });
-#endif
 
     QQmlComponent *component = new QQmlComponent(d->configModule->engine(), this);
     component->setData(QByteArrayLiteral("import QtQuick 2.3\nItem{}"), QUrl());
